from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import statement_pb2 as _statement_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StatementChangedEvent(_message.Message):
    __slots__ = ("problem_id", "before", "after")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    before: _statement_pb2.Statement
    after: _statement_pb2.Statement
    def __init__(self, problem_id: _Optional[str] = ..., before: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ..., after: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class ListStatementsInput(_message.Message):
    __slots__ = ("offset", "size", "render", "version", "extra")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    render: bool
    version: int
    extra: _containers.RepeatedScalarFieldContainer[_statement_pb2.Statement.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., render: bool = ..., version: _Optional[int] = ..., extra: _Optional[_Iterable[_Union[_statement_pb2.Statement.Extra, str]]] = ...) -> None: ...

class ListStatementsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_statement_pb2.Statement]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_statement_pb2.Statement, _Mapping]]] = ...) -> None: ...

class TranslateStatementsInput(_message.Message):
    __slots__ = ("source", "target", "target_automatic", "override_manual")
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    TARGET_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_MANUAL_FIELD_NUMBER: _ClassVar[int]
    source: str
    target: _containers.RepeatedScalarFieldContainer[str]
    target_automatic: bool
    override_manual: bool
    def __init__(self, source: _Optional[str] = ..., target: _Optional[_Iterable[str]] = ..., target_automatic: bool = ..., override_manual: bool = ...) -> None: ...

class TranslateStatementsOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class DescribeStatementInput(_message.Message):
    __slots__ = ("statement_id", "render", "version", "extra")
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    statement_id: str
    render: bool
    version: int
    extra: _containers.RepeatedScalarFieldContainer[_statement_pb2.Statement.Extra]
    def __init__(self, statement_id: _Optional[str] = ..., render: bool = ..., version: _Optional[int] = ..., extra: _Optional[_Iterable[_Union[_statement_pb2.Statement.Extra, str]]] = ...) -> None: ...

class DescribeStatementOutput(_message.Message):
    __slots__ = ("statement",)
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class LookupStatementInput(_message.Message):
    __slots__ = ("locale", "render", "version", "extra")
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    locale: str
    render: bool
    version: int
    extra: _containers.RepeatedScalarFieldContainer[_statement_pb2.Statement.Extra]
    def __init__(self, locale: _Optional[str] = ..., render: bool = ..., version: _Optional[int] = ..., extra: _Optional[_Iterable[_Union[_statement_pb2.Statement.Extra, str]]] = ...) -> None: ...

class LookupStatementOutput(_message.Message):
    __slots__ = ("statement",)
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class PreviewStatementInput(_message.Message):
    __slots__ = ("statement",)
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class PreviewStatementOutput(_message.Message):
    __slots__ = ("statement",)
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class CreateStatementInput(_message.Message):
    __slots__ = ("statement",)
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class CreateStatementOutput(_message.Message):
    __slots__ = ("statement_id",)
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    statement_id: str
    def __init__(self, statement_id: _Optional[str] = ...) -> None: ...

class UpdateStatementInput(_message.Message):
    __slots__ = ("patch", "statement_id", "statement")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_statement_pb2.Statement.Patch]
    statement_id: str
    statement: _statement_pb2.Statement
    def __init__(self, patch: _Optional[_Iterable[_Union[_statement_pb2.Statement.Patch, str]]] = ..., statement_id: _Optional[str] = ..., statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class UpdateStatementOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteStatementInput(_message.Message):
    __slots__ = ("statement_id",)
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    statement_id: str
    def __init__(self, statement_id: _Optional[str] = ...) -> None: ...

class DeleteStatementOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExportStatementInput(_message.Message):
    __slots__ = ("statement_id",)
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    statement_id: str
    def __init__(self, statement_id: _Optional[str] = ...) -> None: ...

class ExportStatementOutput(_message.Message):
    __slots__ = ("download_url",)
    DOWNLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    download_url: str
    def __init__(self, download_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/events.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/content/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.content import fragment_pb2 as eolymp_dot_content_dot_fragment__pb2
from eolymp.content import variant_pb2 as eolymp_dot_content_dot_variant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/content/events.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/content/fragment.proto\x1a\x1c\x65olymp/content/variant.proto\"x\n\x14\x46ragmentChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"{\n\x13VariantChangedEvent\x12\x13\n\x0b\x66ragment_id\x18\n \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.content.Variant\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.content.VariantB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_start=108
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_end=228
  _globals['_VARIANTCHANGEDEVENT']._serialized_start=230
  _globals['_VARIANTCHANGEDEVENT']._serialized_end=353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/invoice.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/commerce/invoice.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import price_pb2 as eolymp_dot_commerce_dot_price__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/commerce/invoice.proto\x12\x0f\x65olymp.commerce\x1a\x1b\x65olymp/commerce/price.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\n\n\x07Invoice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\t\x12/\n\x06status\x18\x03 \x01(\x0e\x32\x1f.eolymp.commerce.Invoice.Status\x12\x13\n\x0b\x63ustomer_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x0c\x66rom_invoice\x18\x06 \x01(\x0b\x32$.eolymp.commerce.Invoice.FromInvoice\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x64ue_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12hosted_invoice_url\x18\x1f \x01(\t\x12\x17\n\x0finvoice_pdf_url\x18  \x01(\t\x12\x10\n\x08\x63urrency\x18\x64 \x01(\t\x12\x12\n\namount_due\x18x \x01(\x05\x12\x13\n\x0b\x61mount_paid\x18y \x01(\x05\x12\x18\n\x10\x61mount_remaining\x18z \x01(\x05\x12\x11\n\x08subtotal\x18\x82\x01 \x01(\x05\x12\x1f\n\x16subtotal_excluding_tax\x18\x83\x01 \x01(\x05\x12\x38\n\x0btax_amounts\x18\x8d\x01 \x03(\x0b\x32\".eolymp.commerce.Invoice.TaxAmount\x12\x0c\n\x03tax\x18\x8c\x01 \x01(\x05\x12\x42\n\x10\x64iscount_amounts\x18\x96\x01 \x03(\x0b\x32\'.eolymp.commerce.Invoice.DiscountAmount\x12\x0e\n\x05total\x18\xc8\x01 \x01(\x05\x12\x1c\n\x13total_excluding_tax\x18\xc9\x01 \x01(\x05\x12-\n\x05items\x18\xe7\x07 \x03(\x0b\x32\x1d.eolymp.commerce.Invoice.Item\x1a\xbf\x02\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\n \x01(\r\x12%\n\x05price\x18\x14 \x01(\x0b\x32\x16.eolymp.commerce.Price\x12\x10\n\x08\x63urrency\x18\x64 \x01(\t\x12\x0e\n\x06\x61mount\x18\x65 \x01(\x05\x12\x1c\n\x14\x61mount_excluding_tax\x18\x66 \x01(\x05\x12!\n\x19unit_amount_excluding_tax\x18g \x01(\x05\x12\x41\n\x10\x64iscount_amounts\x18h \x03(\x0b\x32\'.eolymp.commerce.Invoice.DiscountAmount\x12\x37\n\x0btax_amounts\x18i \x03(\x0b\x32\".eolymp.commerce.Invoice.TaxAmount\x1as\n\tTaxAmount\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\x12\x11\n\tinclusive\x18\x02 \x01(\x08\x12\x10\n\x08tax_rate\x18\x03 \x01(\t\x12\x19\n\x11taxability_reason\x18\x04 \x01(\t\x12\x16\n\x0etaxable_amount\x18\n \x01(\x05\x1a\x32\n\x0e\x44iscountAmount\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\x12\x10\n\x08\x64iscount\x18\x02 \x01(\t\x1a\x30\n\x0b\x46romInvoice\x12\x10\n\x08relation\x18\x01 \x01(\t\x12\x0f\n\x07invoice\x18\x02 \x01(\t\"X\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x08\n\x04PAID\x10\x03\x12\x11\n\rUNCOLLECTIBLE\x10\x04\x12\x08\n\x04VOID\x10\x05\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.invoice_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_INVOICE']._serialized_start=113
  _globals['_INVOICE']._serialized_end=1447
  _globals['_INVOICE_ITEM']._serialized_start=819
  _globals['_INVOICE_ITEM']._serialized_end=1138
  _globals['_INVOICE_TAXAMOUNT']._serialized_start=1140
  _globals['_INVOICE_TAXAMOUNT']._serialized_end=1255
  _globals['_INVOICE_DISCOUNTAMOUNT']._serialized_start=1257
  _globals['_INVOICE_DISCOUNTAMOUNT']._serialized_end=1307
  _globals['_INVOICE_FROMINVOICE']._serialized_start=1309
  _globals['_INVOICE_FROMINVOICE']._serialized_end=1357
  _globals['_INVOICE_STATUS']._serialized_start=1359
  _globals['_INVOICE_STATUS']._serialized_end=1447
# @@protoc_insertion_point(module_scope)



from .problem_service_pb2 import *
from .module_pb2 import *
from .student_service_http import *
from .module_service_pb2 import *
from .submission_service_http import *
from .student_service_pb2 import *
from .material_pb2 import *
from .events_pb2 import *
from .class_pb2 import *
from .class_service_http import *
from .student_pb2 import *
from .material_service_http import *
from .submission_service_pb2 import *
from .course_service_http import *
from .module_service_http import *
from .problem_service_http import *
from .assignment_pb2 import *
from .course_pb2 import *
from .class_service_pb2 import *
from .course_service_pb2 import *
from .material_service_pb2 import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class MaterialServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateMaterial(self, request, **kwargs):
        path = "/materials"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.CreateMaterialOutput"),
            **kwargs,
        )

    def UpdateMaterial(self, request, **kwargs):
        path = "/materials/"+urllib.parse.quote(request.material_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.material_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.UpdateMaterialOutput"),
            **kwargs,
        )

    def MoveMaterial(self, request, **kwargs):
        path = "/materials/"+urllib.parse.quote(request.material_id)+"/move"

        # Cleanup URL parameters to avoid any ambiguity
        request.material_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.MoveMaterialOutput"),
            **kwargs,
        )

    def DeleteMaterial(self, request, **kwargs):
        path = "/materials/"+urllib.parse.quote(request.material_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.material_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DeleteMaterialOutput"),
            **kwargs,
        )

    def DescribeMaterial(self, request, **kwargs):
        path = "/materials/"+urllib.parse.quote(request.material_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.material_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeMaterialOutput"),
            **kwargs,
        )

    def ListMaterials(self, request, **kwargs):
        path = "/materials"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListMaterialsOutput"),
            **kwargs,
        )

    def ReportProgress(self, request, **kwargs):
        path = "/materials/"+urllib.parse.quote(request.material_id)+"/progress"

        # Cleanup URL parameters to avoid any ambiguity
        request.material_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ReportProgressOutput"),
            **kwargs,
        )

    def GradeMaterial(self, request, **kwargs):
        path = "/materials/"+urllib.parse.quote(request.material_id)+"/grade"

        # Cleanup URL parameters to avoid any ambiguity
        request.material_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.GradeMaterialOutput"),
            **kwargs,
        )




from eolymp.content import fragment_pb2 as _fragment_pb2
from eolymp.content import variant_pb2 as _variant_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FragmentChangedEvent(_message.Message):
    __slots__ = ("scope", "before", "after")
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    scope: str
    before: _fragment_pb2.Fragment
    after: _fragment_pb2.Fragment
    def __init__(self, scope: _Optional[str] = ..., before: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ..., after: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class VariantChangedEvent(_message.Message):
    __slots__ = ("fragment_id", "before", "after")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    before: _variant_pb2.Variant
    after: _variant_pb2.Variant
    def __init__(self, fragment_id: _Optional[str] = ..., before: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ..., after: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class PostServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribePost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DescribePostOutput"),
            **kwargs,
        )

    def ListPosts(self, request, **kwargs):
        path = "/posts"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ListPostsOutput"),
            **kwargs,
        )

    def CreatePost(self, request, **kwargs):
        path = "/posts"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.CreatePostOutput"),
            **kwargs,
        )

    def UpdatePost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UpdatePostOutput"),
            **kwargs,
        )

    def PublishPost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/publish"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.PublishPostOutput"),
            **kwargs,
        )

    def UnpublishPost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/publish"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UnpublishPostOutput"),
            **kwargs,
        )

    def ModeratePost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/moderate"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ModeratePostOutput"),
            **kwargs,
        )

    def DeletePost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DeletePostOutput"),
            **kwargs,
        )

    def VotePost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/vote"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.VotePostOutput"),
            **kwargs,
        )

    def TranslatePost(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/translate"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.TranslatePostOutput"),
            **kwargs,
        )

    def DescribePostTranslation(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DescribePostTranslationOutput"),
            **kwargs,
        )

    def ListPostTranslations(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ListPostTranslationsOutput"),
            **kwargs,
        )

    def CreatePostTranslation(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.CreatePostTranslationOutput"),
            **kwargs,
        )

    def UpdatePostTranslation(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UpdatePostTranslationOutput"),
            **kwargs,
        )

    def DeletePostTranslation(self, request, **kwargs):
        path = "/posts/"+urllib.parse.quote(request.post_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.post_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DeletePostTranslationOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/configuration.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/configuration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/discussion/configuration.proto\x12\x11\x65olymp.discussion\"\xf1\x02\n\rConfiguration\x12 \n\x18members_can_create_posts\x18\x01 \x01(\x08\x12$\n\x1cmembers_can_comment_on_posts\x18\x02 \x01(\x08\x12\'\n\x1fmembers_can_comment_on_problems\x18\x03 \x01(\x08\x12\x44\n\x0fpost_moderation\x18\x04 \x01(\x0e\x32+.eolymp.discussion.Configuration.Moderation\x12G\n\x12\x63omment_moderation\x18\x05 \x01(\x0e\x32+.eolymp.discussion.Configuration.Moderation\"`\n\nModeration\x12\x16\n\x12UNKNOWN_MODERATION\x10\x00\x12\x11\n\rNO_MODERATION\x10\x01\x12\x12\n\x0ePRE_MODERATION\x10\x02\x12\x13\n\x0fPOST_MODERATION\x10\x03\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.configuration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_CONFIGURATION']._serialized_start=61
  _globals['_CONFIGURATION']._serialized_end=430
  _globals['_CONFIGURATION_MODERATION']._serialized_start=334
  _globals['_CONFIGURATION_MODERATION']._serialized_end=430
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Score(_message.Message):
    __slots__ = ("id", "user_id", "member_id", "solved_at", "score", "attempts")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    SOLVED_AT_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    member_id: str
    solved_at: _timestamp_pb2.Timestamp
    score: float
    attempts: int
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., member_id: _Optional[str] = ..., solved_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., score: _Optional[float] = ..., attempts: _Optional[int] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Score(_message.Message):
    __slots__ = ("valid_after", "valid_until", "timestamp", "score", "penalty", "tie_breaker", "upsolve", "breakdown")
    class FetchingMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ACTUAL: _ClassVar[Score.FetchingMode]
        PUNCTUAL: _ClassVar[Score.FetchingMode]
        LATEST: _ClassVar[Score.FetchingMode]
        FROZEN: _ClassVar[Score.FetchingMode]
        UPSOLVE: _ClassVar[Score.FetchingMode]
    ACTUAL: Score.FetchingMode
    PUNCTUAL: Score.FetchingMode
    LATEST: Score.FetchingMode
    FROZEN: Score.FetchingMode
    UPSOLVE: Score.FetchingMode
    class Problem(_message.Message):
        __slots__ = ("problem_id", "score", "penalty", "solved", "percentage", "attempts", "solved_at", "solved_in", "changed", "breakdown")
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        SOLVED_FIELD_NUMBER: _ClassVar[int]
        PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
        ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
        SOLVED_AT_FIELD_NUMBER: _ClassVar[int]
        SOLVED_IN_FIELD_NUMBER: _ClassVar[int]
        CHANGED_FIELD_NUMBER: _ClassVar[int]
        BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
        problem_id: str
        score: float
        penalty: float
        solved: bool
        percentage: float
        attempts: int
        solved_at: _timestamp_pb2.Timestamp
        solved_in: int
        changed: bool
        breakdown: _containers.RepeatedCompositeFieldContainer[Score.Testset]
        def __init__(self, problem_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., solved: bool = ..., percentage: _Optional[float] = ..., attempts: _Optional[int] = ..., solved_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., solved_in: _Optional[int] = ..., changed: bool = ..., breakdown: _Optional[_Iterable[_Union[Score.Testset, _Mapping]]] = ...) -> None: ...
    class Testset(_message.Message):
        __slots__ = ("testset_id", "index", "cost", "score")
        TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        testset_id: str
        index: int
        cost: float
        score: float
        def __init__(self, testset_id: _Optional[str] = ..., index: _Optional[int] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ...) -> None: ...
    VALID_AFTER_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    PENALTY_FIELD_NUMBER: _ClassVar[int]
    TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
    valid_after: int
    valid_until: int
    timestamp: _timestamp_pb2.Timestamp
    score: float
    penalty: float
    tie_breaker: int
    upsolve: bool
    breakdown: _containers.RepeatedCompositeFieldContainer[Score.Problem]
    def __init__(self, valid_after: _Optional[int] = ..., valid_until: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., tie_breaker: _Optional[int] = ..., upsolve: bool = ..., breakdown: _Optional[_Iterable[_Union[Score.Problem, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/score_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/score_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import result_pb2 as eolymp_dot_judge_dot_result__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/judge/score_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/judge/result.proto\x1a\x18\x65olymp/judge/score.proto\"\'\n\x11RebuildScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\")\n\x12RebuildScoreOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\"*\n\x14IntrospectScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\";\n\x15IntrospectScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"m\n\x0fWatchScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x04mode\x18\x03 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\"6\n\x10WatchScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"\x85\x01\n\x12\x44\x65scribeScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x04mode\x18\x03 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x04 \x01(\x05\"9\n\x13\x44\x65scribeScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"c\n\x10ImportScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12#\n\x06scores\x18\n \x03(\x0b\x32\x13.eolymp.judge.Score\"\x13\n\x11ImportScoreOutput\">\n\x10\x45xportScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"8\n\x11\x45xportScoreOutput\x12#\n\x06scores\x18\n \x03(\x0b\x32\x13.eolymp.judge.Score\"\x88\x01\n\x0fListResultInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x10ListResultOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Result\"l\n\x11\x45xportResultInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\"(\n\x12\x45xportResultOutput\x12\x12\n\nexport_url\x18\x01 \x01(\t2\xb3\t\n\x0cScoreService\x12\x84\x01\n\x0fIntrospectScore\x12\".eolymp.judge.IntrospectScoreInput\x1a#.eolymp.judge.IntrospectScoreOutput\"(\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x13\x12\x11/introspect/score\x12i\n\nWatchScore\x12\x1d.eolymp.judge.WatchScoreInput\x1a\x1e.eolymp.judge.WatchScoreOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xac\x01\n\rDescribeScore\x12 .eolymp.judge.DescribeScoreInput\x1a!.eolymp.judge.DescribeScoreOutput\"V\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02&\x12$/participants/{participant_id}/score\x12\xa7\x01\n\x0bImportScore\x12\x1e.eolymp.judge.ImportScoreInput\x1a\x1f.eolymp.judge.ImportScoreOutput\"W\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\'\"%/participants/{participant_id}/scores\x12\xa7\x01\n\x0b\x45xportScore\x12\x1e.eolymp.judge.ExportScoreInput\x1a\x1f.eolymp.judge.ExportScoreOutput\"W\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\'\x12%/participants/{participant_id}/scores\x12\x87\x01\n\nListResult\x12\x1d.eolymp.judge.ListResultInput\x1a\x1e.eolymp.judge.ListResultOutput\":\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\n\x12\x08/results\x12\x93\x01\n\x0c\x45xportResult\x12\x1f.eolymp.judge.ExportResultInput\x1a .eolymp.judge.ExportResultOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x11\"\x0f/results-export\x12\x8d\x01\n\x0cRebuildScore\x12\x1f.eolymp.judge.RebuildScoreInput\x1a .eolymp.judge.RebuildScoreOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\n\"\x08/rebuildB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.score_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_SCORESERVICE'].methods_by_name['IntrospectScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['IntrospectScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\023\022\021/introspect/score'
  _globals['_SCORESERVICE'].methods_by_name['WatchScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['WatchScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_SCORESERVICE'].methods_by_name['DescribeScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['DescribeScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002&\022$/participants/{participant_id}/score'
  _globals['_SCORESERVICE'].methods_by_name['ImportScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ImportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\'\"%/participants/{participant_id}/scores'
  _globals['_SCORESERVICE'].methods_by_name['ExportScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ExportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\'\022%/participants/{participant_id}/scores'
  _globals['_SCORESERVICE'].methods_by_name['ListResult']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ListResult']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\n\022\010/results'
  _globals['_SCORESERVICE'].methods_by_name['ExportResult']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ExportResult']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\021\"\017/results-export'
  _globals['_SCORESERVICE'].methods_by_name['RebuildScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['RebuildScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\n\"\010/rebuild'
  _globals['_REBUILDSCOREINPUT']._serialized_start=202
  _globals['_REBUILDSCOREINPUT']._serialized_end=241
  _globals['_REBUILDSCOREOUTPUT']._serialized_start=243
  _globals['_REBUILDSCOREOUTPUT']._serialized_end=284
  _globals['_INTROSPECTSCOREINPUT']._serialized_start=286
  _globals['_INTROSPECTSCOREINPUT']._serialized_end=328
  _globals['_INTROSPECTSCOREOUTPUT']._serialized_start=330
  _globals['_INTROSPECTSCOREOUTPUT']._serialized_end=389
  _globals['_WATCHSCOREINPUT']._serialized_start=391
  _globals['_WATCHSCOREINPUT']._serialized_end=500
  _globals['_WATCHSCOREOUTPUT']._serialized_start=502
  _globals['_WATCHSCOREOUTPUT']._serialized_end=556
  _globals['_DESCRIBESCOREINPUT']._serialized_start=559
  _globals['_DESCRIBESCOREINPUT']._serialized_end=692
  _globals['_DESCRIBESCOREOUTPUT']._serialized_start=694
  _globals['_DESCRIBESCOREOUTPUT']._serialized_end=751
  _globals['_IMPORTSCOREINPUT']._serialized_start=753
  _globals['_IMPORTSCOREINPUT']._serialized_end=852
  _globals['_IMPORTSCOREOUTPUT']._serialized_start=854
  _globals['_IMPORTSCOREOUTPUT']._serialized_end=873
  _globals['_EXPORTSCOREINPUT']._serialized_start=875
  _globals['_EXPORTSCOREINPUT']._serialized_end=937
  _globals['_EXPORTSCOREOUTPUT']._serialized_start=939
  _globals['_EXPORTSCOREOUTPUT']._serialized_end=995
  _globals['_LISTRESULTINPUT']._serialized_start=998
  _globals['_LISTRESULTINPUT']._serialized_end=1134
  _globals['_LISTRESULTOUTPUT']._serialized_start=1136
  _globals['_LISTRESULTOUTPUT']._serialized_end=1206
  _globals['_EXPORTRESULTINPUT']._serialized_start=1208
  _globals['_EXPORTRESULTINPUT']._serialized_end=1316
  _globals['_EXPORTRESULTOUTPUT']._serialized_start=1318
  _globals['_EXPORTRESULTOUTPUT']._serialized_end=1358
  _globals['_SCORESERVICE']._serialized_start=1361
  _globals['_SCORESERVICE']._serialized_end=2564
# @@protoc_insertion_point(module_scope)



from eolymp.course import assignment_pb2 as _assignment_pb2
from eolymp.course import material_pb2 as _material_pb2
from eolymp.course import module_pb2 as _module_pb2
from eolymp.course import student_pb2 as _student_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModuleChangedEvent(_message.Message):
    __slots__ = ("course_id", "before", "after")
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    before: _module_pb2.Module
    after: _module_pb2.Module
    def __init__(self, course_id: _Optional[str] = ..., before: _Optional[_Union[_module_pb2.Module, _Mapping]] = ..., after: _Optional[_Union[_module_pb2.Module, _Mapping]] = ...) -> None: ...

class MaterialChangedEvent(_message.Message):
    __slots__ = ("course_id", "before", "after")
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    before: _material_pb2.Material
    after: _material_pb2.Material
    def __init__(self, course_id: _Optional[str] = ..., before: _Optional[_Union[_material_pb2.Material, _Mapping]] = ..., after: _Optional[_Union[_material_pb2.Material, _Mapping]] = ...) -> None: ...

class StudentChangedEvent(_message.Message):
    __slots__ = ("course_id", "before", "after")
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    before: _student_pb2.Student
    after: _student_pb2.Student
    def __init__(self, course_id: _Optional[str] = ..., before: _Optional[_Union[_student_pb2.Student, _Mapping]] = ..., after: _Optional[_Union[_student_pb2.Student, _Mapping]] = ...) -> None: ...

class AssignmentChangedEvent(_message.Message):
    __slots__ = ("course_id", "module_id", "before", "after")
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    module_id: str
    before: _assignment_pb2.Assignment
    after: _assignment_pb2.Assignment
    def __init__(self, course_id: _Optional[str] = ..., module_id: _Optional[str] = ..., before: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ..., after: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ...) -> None: ...



from eolymp.executor import file_pb2 as _file_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Script(_message.Message):
    __slots__ = ("name", "runtime", "source_url", "header_url", "footer_url", "files")
    NAME_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    HEADER_URL_FIELD_NUMBER: _ClassVar[int]
    FOOTER_URL_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    name: str
    runtime: str
    source_url: str
    header_url: str
    footer_url: str
    files: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    def __init__(self, name: _Optional[str] = ..., runtime: _Optional[str] = ..., source_url: _Optional[str] = ..., header_url: _Optional[str] = ..., footer_url: _Optional[str] = ..., files: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/solution.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/solution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/atlas/solution.proto\x12\x0c\x65olymp.atlas\"\xbb\x03\n\x08Solution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\x08\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12)\n\x04type\x18\x14 \x01(\x0e\x32\x1b.eolymp.atlas.Solution.Type\x12-\n\x06status\x18\x1e \x01(\x0e\x32\x1d.eolymp.atlas.Solution.Status\x12\x15\n\rsubmission_id\x18\x1f \x01(\t\"\xa8\x01\n\x04Type\x12\t\n\x05UNSET\x10\x00\x12\x0b\n\x07\x43ORRECT\x10\x01\x12\r\n\tINCORRECT\x10\x02\x12\x10\n\x0cWRONG_ANSWER\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08OVERFLOW\x10\x05\x12\x17\n\x13TIMEOUT_OR_ACCEPTED\x10\x06\x12\x18\n\x14OVERFLOW_OR_ACCEPTED\x10\x07\x12\x0c\n\x08\x44ONT_RUN\x10\x08\x12\x0b\n\x07\x46\x41ILURE\x10\t\"H\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\t\x12\x08\n\x04PASS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.solution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SOLUTION']._serialized_start=46
  _globals['_SOLUTION']._serialized_end=489
  _globals['_SOLUTION_TYPE']._serialized_start=247
  _globals['_SOLUTION_TYPE']._serialized_end=415
  _globals['_SOLUTION_STATUS']._serialized_start=417
  _globals['_SOLUTION_STATUS']._serialized_end=489
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/resolver/resolver.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/resolver/resolver.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.universe import space_pb2 as eolymp_dot_universe_dot_space__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/resolver/resolver.proto\x12\x0f\x65olymp.resolver\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a\x1b\x65olymp/universe/space.proto\"\x96\x01\n\rAuthorization\x1a\x84\x01\n\x06OAuth2\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0etoken_endpoint\x18\x02 \x01(\t\x12\x1a\n\x12\x61uthorize_endpoint\x18\x03 \x01(\t\x12\x19\n\x11userinfo_endpoint\x18\x04 \x01(\t\x12\x18\n\x10signout_endpoint\x18\x05 \x01(\t\"\xbc\x01\n\x06Record\x12.\n\x06target\x18\x14 \x01(\x0b\x32\x1e.eolymp.resolver.Record.Target\x1a\x41\n\x06Target\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.eolymp.resolver.Record.Type\x12\x0b\n\x03url\x18\x02 \x01(\t\"?\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05SPACE\x10\x01\x12\x0b\n\x07\x43ONTEST\x10\x02\x12\x0e\n\nSCOREBOARD\x10\x03\" \n\x10ResolveNameInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x93\x02\n\x11ResolveNameOutput\x12.\n\x06target\x18\x01 \x01(\x0b\x32\x1e.eolymp.resolver.Record.Target\x12\'\n\x05space\x18\n \x01(\x0b\x32\x16.eolymp.universe.SpaceH\x00\x12(\n\x07\x63ontest\x18\x0b \x01(\x0b\x32\x15.eolymp.judge.ContestH\x00\x12/\n\nscoreboard\x18\x0c \x01(\x0b\x32\x19.eolymp.ranker.ScoreboardH\x00\x12\x37\n\x06oauth2\x18\x14 \x01(\x0b\x32%.eolymp.resolver.Authorization.OAuth2H\x01\x42\t\n\x07targetxB\x06\n\x04\x61uth2\x86\x01\n\x08Resolver\x12z\n\x0bResolveName\x12!.eolymp.resolver.ResolveNameInput\x1a\".eolymp.resolver.ResolveNameOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00HB\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\x12\r/names/{name}B3Z1github.com/eolymp/go-sdk/eolymp/resolver;resolverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.resolver.resolver_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/resolver;resolver'
  _globals['_RESOLVER'].methods_by_name['ResolveName']._loaded_options = None
  _globals['_RESOLVER'].methods_by_name['ResolveName']._serialized_options = b'\352\342\n\013\365\342\n\000\000HB\370\342\nd\202\323\344\223\002\017\022\r/names/{name}'
  _globals['_AUTHORIZATION']._serialized_start=208
  _globals['_AUTHORIZATION']._serialized_end=358
  _globals['_AUTHORIZATION_OAUTH2']._serialized_start=226
  _globals['_AUTHORIZATION_OAUTH2']._serialized_end=358
  _globals['_RECORD']._serialized_start=361
  _globals['_RECORD']._serialized_end=549
  _globals['_RECORD_TARGET']._serialized_start=419
  _globals['_RECORD_TARGET']._serialized_end=484
  _globals['_RECORD_TYPE']._serialized_start=486
  _globals['_RECORD_TYPE']._serialized_end=549
  _globals['_RESOLVENAMEINPUT']._serialized_start=551
  _globals['_RESOLVENAMEINPUT']._serialized_end=583
  _globals['_RESOLVENAMEOUTPUT']._serialized_start=586
  _globals['_RESOLVENAMEOUTPUT']._serialized_end=861
  _globals['_RESOLVER']._serialized_start=864
  _globals['_RESOLVER']._serialized_end=998
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Node(_message.Message):
    __slots__ = ("type", "attr", "children")
    class AttrEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ATTR_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    type: str
    attr: _containers.ScalarMap[str, str]
    children: _containers.RepeatedCompositeFieldContainer[Node]
    def __init__(self, type: _Optional[str] = ..., attr: _Optional[_Mapping[str, str]] = ..., children: _Optional[_Iterable[_Union[Node, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.discussion import message_pb2 as _message_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageChangedEvent(_message.Message):
    __slots__ = ("scope", "before", "after", "reason")
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    scope: str
    before: _message_pb2.Message
    after: _message_pb2.Message
    reason: str
    def __init__(self, scope: _Optional[str] = ..., before: _Optional[_Union[_message_pb2.Message, _Mapping]] = ..., after: _Optional[_Union[_message_pb2.Message, _Mapping]] = ..., reason: _Optional[str] = ...) -> None: ...

class DescribeMessageInput(_message.Message):
    __slots__ = ("message_id", "render", "extra")
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    render: bool
    extra: _containers.RepeatedScalarFieldContainer[_message_pb2.Message.Extra]
    def __init__(self, message_id: _Optional[str] = ..., render: bool = ..., extra: _Optional[_Iterable[_Union[_message_pb2.Message.Extra, str]]] = ...) -> None: ...

class DescribeMessageOutput(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: _message_pb2.Message
    def __init__(self, message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...) -> None: ...

class ListMessagesInput(_message.Message):
    __slots__ = ("render", "after", "size", "sort", "order", "filters", "extra")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListMessagesInput.Sortable]
        POSTED_AT: _ClassVar[ListMessagesInput.Sortable]
        VOTE_COUNT: _ClassVar[ListMessagesInput.Sortable]
        REPLY_COUNT: _ClassVar[ListMessagesInput.Sortable]
    DEFAULT: ListMessagesInput.Sortable
    POSTED_AT: ListMessagesInput.Sortable
    VOTE_COUNT: ListMessagesInput.Sortable
    REPLY_COUNT: ListMessagesInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("query", "id", "reply_to", "member_id", "thread_id", "vote_count", "reply_count", "posted_at")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        REPLY_TO_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        THREAD_ID_FIELD_NUMBER: _ClassVar[int]
        VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
        REPLY_COUNT_FIELD_NUMBER: _ClassVar[int]
        POSTED_AT_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        reply_to: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        thread_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        vote_count: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        reply_count: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        posted_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., reply_to: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., thread_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., vote_count: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., reply_count: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., posted_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ...) -> None: ...
    RENDER_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    render: bool
    after: str
    size: int
    sort: ListMessagesInput.Sortable
    order: _direction_pb2.Direction
    filters: ListMessagesInput.Filter
    extra: _containers.RepeatedScalarFieldContainer[_message_pb2.Message.Extra]
    def __init__(self, render: bool = ..., after: _Optional[str] = ..., size: _Optional[int] = ..., sort: _Optional[_Union[ListMessagesInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., filters: _Optional[_Union[ListMessagesInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_message_pb2.Message.Extra, str]]] = ...) -> None: ...

class ListMessagesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_message_pb2.Message]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_message_pb2.Message, _Mapping]]] = ...) -> None: ...

class PostMessageInput(_message.Message):
    __slots__ = ("message", "reply_to")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REPLY_TO_FIELD_NUMBER: _ClassVar[int]
    message: _message_pb2.Message
    reply_to: str
    def __init__(self, message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ..., reply_to: _Optional[str] = ...) -> None: ...

class PostMessageOutput(_message.Message):
    __slots__ = ("message_id",)
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    def __init__(self, message_id: _Optional[str] = ...) -> None: ...

class UpdateMessageInput(_message.Message):
    __slots__ = ("message_id", "message")
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    message: _message_pb2.Message
    def __init__(self, message_id: _Optional[str] = ..., message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...) -> None: ...

class UpdateMessageOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteMessageInput(_message.Message):
    __slots__ = ("message_id", "reason")
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    reason: str
    def __init__(self, message_id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class DeleteMessageOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class VoteMessageInput(_message.Message):
    __slots__ = ("message_id", "vote")
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    vote: int
    def __init__(self, message_id: _Optional[str] = ..., vote: _Optional[int] = ...) -> None: ...

class VoteMessageOutput(_message.Message):
    __slots__ = ("vote_count",)
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    vote_count: int
    def __init__(self, vote_count: _Optional[int] = ...) -> None: ...

class ListMessageChangesInput(_message.Message):
    __slots__ = ("message_id",)
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    def __init__(self, message_id: _Optional[str] = ...) -> None: ...

class ListMessageChangesOutput(_message.Message):
    __slots__ = ("history",)
    class Record(_message.Message):
        __slots__ = ("revision", "timestamp", "message")
        REVISION_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        revision: int
        timestamp: _timestamp_pb2.Timestamp
        message: _content_pb2.Content
        def __init__(self, revision: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...
    HISTORY_FIELD_NUMBER: _ClassVar[int]
    history: _containers.RepeatedCompositeFieldContainer[ListMessageChangesOutput.Record]
    def __init__(self, history: _Optional[_Iterable[_Union[ListMessageChangesOutput.Record, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.discussion import configuration_pb2 as _configuration_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeDiscussionConfigInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeDiscussionConfigOutput(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _configuration_pb2.Configuration
    def __init__(self, config: _Optional[_Union[_configuration_pb2.Configuration, _Mapping]] = ...) -> None: ...

class UpdateDiscussionConfigInput(_message.Message):
    __slots__ = ("config",)
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateDiscussionConfigInput.Patch]
        MEMBERS_CAN_CREATE_POSTS: _ClassVar[UpdateDiscussionConfigInput.Patch]
        MEMBERS_CAN_COMMENT_ON_POSTS: _ClassVar[UpdateDiscussionConfigInput.Patch]
        MEMBERS_CAN_COMMENT_ON_PROBLEMS: _ClassVar[UpdateDiscussionConfigInput.Patch]
        POST_MODERATION: _ClassVar[UpdateDiscussionConfigInput.Patch]
        COMMENT_MODERATION: _ClassVar[UpdateDiscussionConfigInput.Patch]
    ALL: UpdateDiscussionConfigInput.Patch
    MEMBERS_CAN_CREATE_POSTS: UpdateDiscussionConfigInput.Patch
    MEMBERS_CAN_COMMENT_ON_POSTS: UpdateDiscussionConfigInput.Patch
    MEMBERS_CAN_COMMENT_ON_PROBLEMS: UpdateDiscussionConfigInput.Patch
    POST_MODERATION: UpdateDiscussionConfigInput.Patch
    COMMENT_MODERATION: UpdateDiscussionConfigInput.Patch
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _configuration_pb2.Configuration
    def __init__(self, config: _Optional[_Union[_configuration_pb2.Configuration, _Mapping]] = ...) -> None: ...

class UpdateDiscussionConfigOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.acl import action_pb2 as _action_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Policy(_message.Message):
    __slots__ = ("id", "name", "principal", "resource", "allow_all", "allows")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_ALL_FIELD_NUMBER: _ClassVar[int]
    ALLOWS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    principal: str
    resource: str
    allow_all: bool
    allows: _containers.RepeatedScalarFieldContainer[_action_pb2.Action]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., principal: _Optional[str] = ..., resource: _Optional[str] = ..., allow_all: bool = ..., allows: _Optional[_Iterable[_Union[_action_pb2.Action, str]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class CampaignServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateCampaign(self, request, **kwargs):
        path = "/campaigns"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.CreateCampaignOutput"),
            **kwargs,
        )

    def UpdateCampaign(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.UpdateCampaignOutput"),
            **kwargs,
        )

    def DeleteCampaign(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DeleteCampaignOutput"),
            **kwargs,
        )

    def DescribeCampaign(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DescribeCampaignOutput"),
            **kwargs,
        )

    def ListCampaigns(self, request, **kwargs):
        path = "/campaigns"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.ListCampaignsOutput"),
            **kwargs,
        )

    def TestCampaign(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/test"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.TestCampaignOutput"),
            **kwargs,
        )

    def SendCampaign(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/send"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.SendCampaignOutput"),
            **kwargs,
        )

    def TranslateCampaign(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/translate"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.TranslateCampaignOutput"),
            **kwargs,
        )

    def CreateTranslation(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.CreateTranslationOutput"),
            **kwargs,
        )

    def UpdateTranslation(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.UpdateTranslationOutput"),
            **kwargs,
        )

    def DeleteTranslation(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DeleteTranslationOutput"),
            **kwargs,
        )

    def DescribeTranslation(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DescribeTranslationOutput"),
            **kwargs,
        )

    def ListTranslations(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.ListTranslationsOutput"),
            **kwargs,
        )

    def CreateRecipient(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/recipients"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.CreateRecipientOutput"),
            **kwargs,
        )

    def ImportRecipient(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/recipients:import"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.ImportRecipientOutput"),
            **kwargs,
        )

    def DeleteRecipient(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/recipients/"+urllib.parse.quote(request.recipient_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""
        request.recipient_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DeleteRecipientOutput"),
            **kwargs,
        )

    def ListRecipients(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/recipients"

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.ListRecipientsOutput"),
            **kwargs,
        )

    def DescribeRecipient(self, request, **kwargs):
        path = "/campaigns/"+urllib.parse.quote(request.campaign_id)+"/recipients/"+urllib.parse.quote(request.recipient_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.campaign_id = ""
        request.recipient_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DescribeRecipientOutput"),
            **kwargs,
        )




from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import email_type_pb2 as _email_type_pb2
from eolymp.community import member_pb2 as _member_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MemberChangedEvent(_message.Message):
    __slots__ = ("before", "after")
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    before: _member_pb2.Member
    after: _member_pb2.Member
    def __init__(self, before: _Optional[_Union[_member_pb2.Member, _Mapping]] = ..., after: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class CreateMemberInput(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class CreateMemberOutput(_message.Message):
    __slots__ = ("member_id",)
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    def __init__(self, member_id: _Optional[str] = ...) -> None: ...

class UpdateMemberInput(_message.Message):
    __slots__ = ("patch", "member_id", "member")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateMemberInput.Patch]
        INACTIVE: _ClassVar[UpdateMemberInput.Patch]
        UNOFFICIAL: _ClassVar[UpdateMemberInput.Patch]
        RATING: _ClassVar[UpdateMemberInput.Patch]
        GROUPS: _ClassVar[UpdateMemberInput.Patch]
        GROUPS_ADD: _ClassVar[UpdateMemberInput.Patch]
        GROUPS_REMOVE: _ClassVar[UpdateMemberInput.Patch]
        ACCOUNT: _ClassVar[UpdateMemberInput.Patch]
        USER_NICKNAME: _ClassVar[UpdateMemberInput.Patch]
        USER_EMAIL: _ClassVar[UpdateMemberInput.Patch]
        USER_PASSWORD: _ClassVar[UpdateMemberInput.Patch]
        USER_NAME: _ClassVar[UpdateMemberInput.Patch]
        USER_PICTURE: _ClassVar[UpdateMemberInput.Patch]
        USER_BIRTHDAY: _ClassVar[UpdateMemberInput.Patch]
        USER_COUNTRY: _ClassVar[UpdateMemberInput.Patch]
        USER_CITY: _ClassVar[UpdateMemberInput.Patch]
        USER_PREFERENCES: _ClassVar[UpdateMemberInput.Patch]
        USER_PREFERENCES_LOCALE: _ClassVar[UpdateMemberInput.Patch]
        USER_PREFERENCES_TIMEZONE: _ClassVar[UpdateMemberInput.Patch]
        USER_PREFERENCES_RUNTIME: _ClassVar[UpdateMemberInput.Patch]
        USER_EMAIL_SUBSCRIPTIONS: _ClassVar[UpdateMemberInput.Patch]
        TEAM_NAME: _ClassVar[UpdateMemberInput.Patch]
        GHOST_NAME: _ClassVar[UpdateMemberInput.Patch]
        ATTRIBUTES: _ClassVar[UpdateMemberInput.Patch]
    ALL: UpdateMemberInput.Patch
    INACTIVE: UpdateMemberInput.Patch
    UNOFFICIAL: UpdateMemberInput.Patch
    RATING: UpdateMemberInput.Patch
    GROUPS: UpdateMemberInput.Patch
    GROUPS_ADD: UpdateMemberInput.Patch
    GROUPS_REMOVE: UpdateMemberInput.Patch
    ACCOUNT: UpdateMemberInput.Patch
    USER_NICKNAME: UpdateMemberInput.Patch
    USER_EMAIL: UpdateMemberInput.Patch
    USER_PASSWORD: UpdateMemberInput.Patch
    USER_NAME: UpdateMemberInput.Patch
    USER_PICTURE: UpdateMemberInput.Patch
    USER_BIRTHDAY: UpdateMemberInput.Patch
    USER_COUNTRY: UpdateMemberInput.Patch
    USER_CITY: UpdateMemberInput.Patch
    USER_PREFERENCES: UpdateMemberInput.Patch
    USER_PREFERENCES_LOCALE: UpdateMemberInput.Patch
    USER_PREFERENCES_TIMEZONE: UpdateMemberInput.Patch
    USER_PREFERENCES_RUNTIME: UpdateMemberInput.Patch
    USER_EMAIL_SUBSCRIPTIONS: UpdateMemberInput.Patch
    TEAM_NAME: UpdateMemberInput.Patch
    GHOST_NAME: UpdateMemberInput.Patch
    ATTRIBUTES: UpdateMemberInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateMemberInput.Patch]
    member_id: str
    member: _member_pb2.Member
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateMemberInput.Patch, str]]] = ..., member_id: _Optional[str] = ..., member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class UpdateMemberOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateMemberPictureInput(_message.Message):
    __slots__ = ("member_id", "filename", "data", "offset_x", "offset_y", "size")
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    OFFSET_X_FIELD_NUMBER: _ClassVar[int]
    OFFSET_Y_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    filename: str
    data: bytes
    offset_x: int
    offset_y: int
    size: int
    def __init__(self, member_id: _Optional[str] = ..., filename: _Optional[str] = ..., data: _Optional[bytes] = ..., offset_x: _Optional[int] = ..., offset_y: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class UpdateMemberPictureOutput(_message.Message):
    __slots__ = ("picture_url",)
    PICTURE_URL_FIELD_NUMBER: _ClassVar[int]
    picture_url: str
    def __init__(self, picture_url: _Optional[str] = ...) -> None: ...

class DeleteMemberInput(_message.Message):
    __slots__ = ("member_id", "force_delete")
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    FORCE_DELETE_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    force_delete: bool
    def __init__(self, member_id: _Optional[str] = ..., force_delete: bool = ...) -> None: ...

class DeleteMemberOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RestoreMemberInput(_message.Message):
    __slots__ = ("member_id",)
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    def __init__(self, member_id: _Optional[str] = ...) -> None: ...

class RestoreMemberOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeMemberInput(_message.Message):
    __slots__ = ("member_id", "extra")
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    extra: _containers.RepeatedScalarFieldContainer[_member_pb2.Member.Extra]
    def __init__(self, member_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_member_pb2.Member.Extra, str]]] = ...) -> None: ...

class DescribeMemberOutput(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class ListMembersInput(_message.Message):
    __slots__ = ("offset", "size", "filters", "search", "sort", "order", "extra")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListMembersInput.Sortable]
        DISPLAY_NAME: _ClassVar[ListMembersInput.Sortable]
        CREATED_AT: _ClassVar[ListMembersInput.Sortable]
        TYPE: _ClassVar[ListMembersInput.Sortable]
        SCORE: _ClassVar[ListMembersInput.Sortable]
    DEFAULT: ListMembersInput.Sortable
    DISPLAY_NAME: ListMembersInput.Sortable
    CREATED_AT: ListMembersInput.Sortable
    TYPE: ListMembersInput.Sortable
    SCORE: ListMembersInput.Sortable
    class ExpressionAttribute(_message.Message):
        __slots__ = ("attribute_key", "number", "string")
        ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        STRING_FIELD_NUMBER: _ClassVar[int]
        attribute_key: str
        number: _expression_pb2.ExpressionInt
        string: _expression_pb2.ExpressionString
        def __init__(self, attribute_key: _Optional[str] = ..., number: _Optional[_Union[_expression_pb2.ExpressionInt, _Mapping]] = ..., string: _Optional[_Union[_expression_pb2.ExpressionString, _Mapping]] = ...) -> None: ...
    class Filter(_message.Message):
        __slots__ = ("id", "type", "display_name", "inactive", "incomplete", "unofficial", "seated", "team_id", "group_id", "user_issuer", "user_subject", "user_email", "user_name", "user_nickname", "birthday", "country", "score", "attribute")
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
        INACTIVE_FIELD_NUMBER: _ClassVar[int]
        INCOMPLETE_FIELD_NUMBER: _ClassVar[int]
        UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
        SEATED_FIELD_NUMBER: _ClassVar[int]
        TEAM_ID_FIELD_NUMBER: _ClassVar[int]
        GROUP_ID_FIELD_NUMBER: _ClassVar[int]
        USER_ISSUER_FIELD_NUMBER: _ClassVar[int]
        USER_SUBJECT_FIELD_NUMBER: _ClassVar[int]
        USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
        USER_NAME_FIELD_NUMBER: _ClassVar[int]
        USER_NICKNAME_FIELD_NUMBER: _ClassVar[int]
        BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        display_name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        inactive: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        incomplete: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        unofficial: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        seated: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        team_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        group_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        user_issuer: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        user_subject: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        user_email: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        user_name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        user_nickname: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        birthday: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        country: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        score: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        attribute: _containers.RepeatedCompositeFieldContainer[ListMembersInput.ExpressionAttribute]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., display_name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., inactive: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., incomplete: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., unofficial: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., seated: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., team_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., group_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_issuer: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., user_subject: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., user_email: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., user_name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., user_nickname: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., birthday: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., country: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., score: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., attribute: _Optional[_Iterable[_Union[ListMembersInput.ExpressionAttribute, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListMembersInput.Filter
    search: str
    sort: ListMembersInput.Sortable
    order: _direction_pb2.Direction
    extra: _containers.RepeatedScalarFieldContainer[_member_pb2.Member.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListMembersInput.Filter, _Mapping]] = ..., search: _Optional[str] = ..., sort: _Optional[_Union[ListMembersInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_member_pb2.Member.Extra, str]]] = ...) -> None: ...

class ListMembersOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_member_pb2.Member]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_member_pb2.Member, _Mapping]]] = ...) -> None: ...

class AssignMemberInput(_message.Message):
    __slots__ = ("team_id", "member_id")
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    team_id: str
    member_id: str
    def __init__(self, team_id: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class AssignMemberOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UnassignMemberInput(_message.Message):
    __slots__ = ("team_id", "member_id")
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    team_id: str
    member_id: str
    def __init__(self, team_id: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class UnassignMemberOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeMemberUsageInput(_message.Message):
    __slots__ = ("period_start", "period_end")
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    period_start: _timestamp_pb2.Timestamp
    period_end: _timestamp_pb2.Timestamp
    def __init__(self, period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DescribeMemberUsageOutput(_message.Message):
    __slots__ = ("total_members", "active_members", "new_members")
    TOTAL_MEMBERS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_MEMBERS_FIELD_NUMBER: _ClassVar[int]
    NEW_MEMBERS_FIELD_NUMBER: _ClassVar[int]
    total_members: int
    active_members: int
    new_members: int
    def __init__(self, total_members: _Optional[int] = ..., active_members: _Optional[int] = ..., new_members: _Optional[int] = ...) -> None: ...



from eolymp.acl import action_pb2 as _action_pb2
from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntrospectPermissionsInput(_message.Message):
    __slots__ = ("resource",)
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: str
    def __init__(self, resource: _Optional[str] = ...) -> None: ...

class IntrospectPermissionsOutput(_message.Message):
    __slots__ = ("actions",)
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    actions: _containers.RepeatedScalarFieldContainer[_action_pb2.Action]
    def __init__(self, actions: _Optional[_Iterable[_Union[_action_pb2.Action, str]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/newsletter/campaign.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/newsletter/campaign.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import email_type_pb2 as eolymp_dot_community_dot_email__type__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/newsletter/campaign.proto\x12\x11\x65olymp.newsletter\x1a!eolymp/community/email_type.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x04\n\x08\x43\x61mpaign\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.eolymp.community.EmailType\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07subject\x18\x0b \x01(\t\x12$\n\x07\x63ontent\x18\x0c \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x18\n\x10recipients_count\x18\x1e \x01(\r\x12\x15\n\rpending_count\x18\x1f \x01(\r\x12\x12\n\nsent_count\x18  \x01(\r\x12\x13\n\x0b\x65rror_count\x18! \x01(\r\x1as\n\x0bTranslation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x66 \x01(\t\x12\x0f\n\x07subject\x18g \x01(\t\x12$\n\x07\x63ontent\x18h \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x11\n\tautomatic\x18i \x01(\x08\"J\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04TYPE\x10\x01\x12\x08\n\x04NAME\x10\x05\x12\x0b\n\x07SUBJECT\x10\x02\x12\x0b\n\x07\x43ONTENT\x10\x03\x12\n\n\x06LOCALE\x10\x04\"A\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x11\n\rCONTENT_VALUE\x10\x01\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x02\x42\x37Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.campaign_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _globals['_CAMPAIGN']._serialized_start=150
  _globals['_CAMPAIGN']._serialized_end=682
  _globals['_CAMPAIGN_TRANSLATION']._serialized_start=424
  _globals['_CAMPAIGN_TRANSLATION']._serialized_end=539
  _globals['_CAMPAIGN_PATCH']._serialized_start=541
  _globals['_CAMPAIGN_PATCH']._serialized_end=615
  _globals['_CAMPAIGN_EXTRA']._serialized_start=617
  _globals['_CAMPAIGN_EXTRA']._serialized_end=682
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Language(_message.Message):
    __slots__ = ("id", "name", "type", "deprecated")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[Language.Type]
        PROGRAMMING: _ClassVar[Language.Type]
        SQL: _ClassVar[Language.Type]
        ML: _ClassVar[Language.Type]
        OTHER: _ClassVar[Language.Type]
    UNKNOWN_TYPE: Language.Type
    PROGRAMMING: Language.Type
    SQL: Language.Type
    ML: Language.Type
    OTHER: Language.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type: Language.Type
    deprecated: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[_Union[Language.Type, str]] = ..., deprecated: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/course.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/course/course.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/course/course.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\"\xfe\x02\n\x06\x43ourse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12(\n\x0b\x64\x65scription\x18\x0c \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x11\n\timage_url\x18\r \x01(\t\x12\x34\n\nvisibility\x18\x0e \x01(\x0e\x32 .eolymp.course.Course.Visibility\x12\x10\n\x08\x64uration\x18\x0f \x01(\r\x12\x0e\n\x06topics\x18\x10 \x03(\t\x12\x10\n\x08\x65stimate\x18\x14 \x01(\r\"I\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\"K\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0c\n\x08UNLISTED\x10\x02\x12\x0b\n\x07PRIVATE\x10\x03\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.course_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_COURSE']._serialized_start=72
  _globals['_COURSE']._serialized_end=454
  _globals['_COURSE_EXTRA']._serialized_start=304
  _globals['_COURSE_EXTRA']._serialized_end=377
  _globals['_COURSE_VISIBILITY']._serialized_start=379
  _globals['_COURSE_VISIBILITY']._serialized_end=454
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/annotations/http.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/annotations/http.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/annotations/http.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"T\n\x04Http\x12#\n\x05rules\x18\x01 \x03(\x0b\x32\x14.eolymp.api.HttpRule\x12\'\n\x1f\x66ully_decode_reserved_expansion\x18\x02 \x01(\x08\"\x81\x02\n\x08HttpRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\r\n\x03get\x18\x02 \x01(\tH\x00\x12\r\n\x03put\x18\x03 \x01(\tH\x00\x12\x0e\n\x04post\x18\x04 \x01(\tH\x00\x12\x10\n\x06\x64\x65lete\x18\x05 \x01(\tH\x00\x12\x0f\n\x05patch\x18\x06 \x01(\tH\x00\x12/\n\x06\x63ustom\x18\x08 \x01(\x0b\x32\x1d.eolymp.api.CustomHttpPatternH\x00\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x15\n\rresponse_body\x18\x0c \x01(\t\x12\x31\n\x13\x61\x64\x64itional_bindings\x18\x0b \x03(\x0b\x32\x14.eolymp.api.HttpRuleB\t\n\x07pattern\"/\n\x11\x43ustomHttpPattern\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t:E\n\x04http\x12\x1e.google.protobuf.MethodOptions\x18\xb0\xca\xbc\" \x01(\x0b\x32\x14.eolymp.api.HttpRuleB9Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.http_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _globals['_HTTP']._serialized_start=79
  _globals['_HTTP']._serialized_end=163
  _globals['_HTTPRULE']._serialized_start=166
  _globals['_HTTPRULE']._serialized_end=423
  _globals['_CUSTOMHTTPPATTERN']._serialized_start=425
  _globals['_CUSTOMHTTPPATTERN']._serialized_end=472
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TestingConfig(_message.Message):
    __slots__ = ("run_count", "interactive_followup")
    RUN_COUNT_FIELD_NUMBER: _ClassVar[int]
    INTERACTIVE_FOLLOWUP_FIELD_NUMBER: _ClassVar[int]
    run_count: int
    interactive_followup: bool
    def __init__(self, run_count: _Optional[int] = ..., interactive_followup: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/admission_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/admission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/judge/admission_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/community/member.proto\"\x17\n\x15RequestAdmissionInput\"8\n\x16RequestAdmissionOutput\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"$\n\x14\x41\x63\x63\x65ptAdmissionInput\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"\x17\n\x15\x41\x63\x63\x65ptAdmissionOutput\"&\n\x16\x44\x65scribeAdmissionInput\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"o\n\x17\x44\x65scribeAdmissionOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12(\n\x06member\x18\x03 \x01(\x0b\x32\x18.eolymp.community.Member\"#\n\x13WatchAdmissionInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\x8a\x01\n\x14WatchAdmissionOutput\x12\x39\n\x06status\x18\x01 \x01(\x0e\x32).eolymp.judge.WatchAdmissionOutput.Status\"7\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x32\x87\x05\n\x10\x41\x64missionService\x12\xa9\x01\n\x10RequestAdmission\x12#.eolymp.judge.RequestAdmissionInput\x1a$.eolymp.judge.RequestAdmissionOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x14\"\x12/admission:request\x12|\n\x0eWatchAdmission\x12!.eolymp.judge.WatchAdmissionInput\x1a\".eolymp.judge.WatchAdmissionOutput\"!\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate0\x01\x12\xa6\x01\n\x11\x44\x65scribeAdmission\x12$.eolymp.judge.DescribeAdmissionInput\x1a%.eolymp.judge.DescribeAdmissionOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x14\x12\x12/admission:request\x12\x9f\x01\n\x0f\x41\x63\x63\x65ptAdmission\x12\".eolymp.judge.AcceptAdmissionInput\x1a#.eolymp.judge.AcceptAdmissionOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x13\"\x11/admission:acceptB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.admission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_ADMISSIONSERVICE'].methods_by_name['RequestAdmission']._loaded_options = None
  _globals['_ADMISSIONSERVICE'].methods_by_name['RequestAdmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\024\"\022/admission:request'
  _globals['_ADMISSIONSERVICE'].methods_by_name['WatchAdmission']._loaded_options = None
  _globals['_ADMISSIONSERVICE'].methods_by_name['WatchAdmission']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate'
  _globals['_ADMISSIONSERVICE'].methods_by_name['DescribeAdmission']._loaded_options = None
  _globals['_ADMISSIONSERVICE'].methods_by_name['DescribeAdmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\024\022\022/admission:request'
  _globals['_ADMISSIONSERVICE'].methods_by_name['AcceptAdmission']._loaded_options = None
  _globals['_ADMISSIONSERVICE'].methods_by_name['AcceptAdmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\023\"\021/admission:accept'
  _globals['_REQUESTADMISSIONINPUT']._serialized_start=184
  _globals['_REQUESTADMISSIONINPUT']._serialized_end=207
  _globals['_REQUESTADMISSIONOUTPUT']._serialized_start=209
  _globals['_REQUESTADMISSIONOUTPUT']._serialized_end=265
  _globals['_ACCEPTADMISSIONINPUT']._serialized_start=267
  _globals['_ACCEPTADMISSIONINPUT']._serialized_end=303
  _globals['_ACCEPTADMISSIONOUTPUT']._serialized_start=305
  _globals['_ACCEPTADMISSIONOUTPUT']._serialized_end=328
  _globals['_DESCRIBEADMISSIONINPUT']._serialized_start=330
  _globals['_DESCRIBEADMISSIONINPUT']._serialized_end=368
  _globals['_DESCRIBEADMISSIONOUTPUT']._serialized_start=370
  _globals['_DESCRIBEADMISSIONOUTPUT']._serialized_end=481
  _globals['_WATCHADMISSIONINPUT']._serialized_start=483
  _globals['_WATCHADMISSIONINPUT']._serialized_end=518
  _globals['_WATCHADMISSIONOUTPUT']._serialized_start=521
  _globals['_WATCHADMISSIONOUTPUT']._serialized_end=659
  _globals['_WATCHADMISSIONOUTPUT_STATUS']._serialized_start=604
  _globals['_WATCHADMISSIONOUTPUT_STATUS']._serialized_end=659
  _globals['_ADMISSIONSERVICE']._serialized_start=662
  _globals['_ADMISSIONSERVICE']._serialized_end=1309
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Class(_message.Message):
    __slots__ = ("id", "group_id", "module_count")
    ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_COUNT_FIELD_NUMBER: _ClassVar[int]
    id: str
    group_id: str
    module_count: int
    def __init__(self, id: _Optional[str] = ..., group_id: _Optional[str] = ..., module_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/stats.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/executor/stats.proto\x12\x0f\x65olymp.executor\"\xb1\x01\n\x05Stats\x12\x11\n\tstdin_url\x18\x01 \x01(\t\x12\x12\n\nstdout_url\x18\x02 \x01(\t\x12\x12\n\nstderr_url\x18\x03 \x01(\t\x12\x1a\n\x12wall_time_duration\x18\x14 \x01(\r\x12\x19\n\x11\x63pu_time_duration\x18\x19 \x01(\r\x12\x13\n\x0bmemory_peak\x18\x1e \x01(\x04\x12\x0e\n\x06signal\x18\x65 \x01(\r\x12\x11\n\texit_code\x18\x64 \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_STATS']._serialized_start=49
  _globals['_STATS']._serialized_end=226
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeActivityGraphInput(_message.Message):
    __slots__ = ("after", "before", "metric")
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    after: _timestamp_pb2.Timestamp
    before: _timestamp_pb2.Timestamp
    metric: str
    def __init__(self, after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., metric: _Optional[str] = ...) -> None: ...

class DescribeActivityGraphOutput(_message.Message):
    __slots__ = ("values", "max_value")
    VALUES_FIELD_NUMBER: _ClassVar[int]
    MAX_VALUE_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[int]
    max_value: int
    def __init__(self, values: _Optional[_Iterable[int]] = ..., max_value: _Optional[int] = ...) -> None: ...



import json
import time
import urllib.parse
import requests


class AccessToken(object):
    def __init__(self, access_token: str = "", refresh_token: str = "", expires_in: int = 0, token_type: str = ""):
        self.access_token = access_token
        self.refresh_token = refresh_token
        self.expires_in = expires_in
        self.token_type = token_type


class OAuthClient:
    def __init__(self, url: str = "https://api.eolymp.com", headers: dict = None, retry: int = 5):
        self._address = url.removesuffix("/") + "/"
        self._headers = headers if headers is not None else {}
        self._retry = retry if retry > 1 else 1

    def token(self, grant_type: str, client_id: str = "", client_secret="", username: str = "", password: str = "",
              code: str = "", code_verifier: str = "", refresh_token: str = "", scope: str = "", **kwargs):

        headers = self._headers
        headers["content-type"] = "application/x-www-form-urlencoded"

        wait = 1
        resp = requests.post(
            url=self._address + "oauth/token",
            headers=headers,
            data=urllib.parse.urlencode({
                "grant_type": grant_type,
                "scope": scope,
                "client_id": client_id,
                "client_secret": client_secret,
                "username": username,
                "password": password,
                "code": code,
                "code_verifier": code_verifier,
                "refresh_token": refresh_token,
            }),

            **kwargs
        )
        for t in range(0, self._retry):

            if resp.status_code == 429:
                time.sleep(wait)
                wait = wait + 1
                continue

            if resp.status_code == 200:
                data = json.loads(resp.content)

                return AccessToken(
                    data["access_token"] if "access_token" in data else "",
                    data["refresh_token"] if "refresh_token" in data else "",
                    data["expires_in"] if "expires_in" in data else 0,
                    data["token_type"] if "token_type" in data else "",
                )
            else:
                raise Exception("Got non-200 response: {}".format(resp.status_code) + str(resp.content))




from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AuthorizeRequestInput(_message.Message):
    __slots__ = ("client_id", "code_challenge", "code_challenge_method", "redirect_uri", "response_type", "scope", "state")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_METHOD_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    code_challenge: str
    code_challenge_method: str
    redirect_uri: str
    response_type: str
    scope: str
    state: str
    def __init__(self, client_id: _Optional[str] = ..., code_challenge: _Optional[str] = ..., code_challenge_method: _Optional[str] = ..., redirect_uri: _Optional[str] = ..., response_type: _Optional[str] = ..., scope: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class AuthorizeRequestOutput(_message.Message):
    __slots__ = ("redirect_uri",)
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    redirect_uri: str
    def __init__(self, redirect_uri: _Optional[str] = ...) -> None: ...

class AuthorizeCallbackInput(_message.Message):
    __slots__ = ("code", "state")
    CODE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    code: str
    state: str
    def __init__(self, code: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class AuthorizeCallbackOutput(_message.Message):
    __slots__ = ("redirect_uri",)
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    redirect_uri: str
    def __init__(self, redirect_uri: _Optional[str] = ...) -> None: ...
